@@ -1,7 +1,9 @@
+import functools
 import itertools
 import urllib.parse
 
 from .common import InfoExtractor
+from .sproutvideo import VidsIoIE
 from .vimeo import VimeoIE
 from ..networking.exceptions import HTTPError
 from ..utils import (
@@ -12,6 +14,7 @@ from ..utils import (
     int_or_none,
     mimetype2ext,
     parse_iso8601,
+    smuggle_url,
     str_or_none,
     traverse_obj,
     url_or_none,
@@ -20,20 +23,26 @@ from ..utils import (
 
 
 class PatreonBaseIE(InfoExtractor):
-    USER_AGENT = 'Patreon/7.6.28 (Android; Android 11; Scale/2.10)'
+    @functools.cached_property
+    def patreon_user_agent(self):
+        # Patreon mobile UA is needed to avoid triggering Cloudflare anti-bot protection.
+        # Newer UA yields higher res m3u8 formats for locked posts, but gives 401 if not logged-in
+        if self._get_cookies('https://www.patreon.com/').get('session_id'):
+            return 'Patreon/72.2.28 (Android; Android 14; Scale/2.10)'
+        return 'Patreon/7.6.28 (Android; Android 11; Scale/2.10)'
 
     def _call_api(self, ep, item_id, query=None, headers=None, fatal=True, note=None):
         if headers is None:
             headers = {}
         if 'User-Agent' not in headers:
-            headers['User-Agent'] = self.USER_AGENT
+            headers['User-Agent'] = self.patreon_user_agent
         if query:
             query.update({'json-api-version': 1.0})
 
         try:
             return self._download_json(
                 f'https://www.patreon.com/api/{ep}',
-                item_id, note='Downloading API JSON' if not note else note,
+                item_id, note=note if note else 'Downloading API JSON',
                 query=query, fatal=fatal, headers=headers)
         except ExtractorError as e:
             if not isinstance(e.cause, HTTPError) or mimetype2ext(e.cause.response.headers.get('Content-Type')) != 'json':
@@ -46,6 +55,7 @@ class PatreonBaseIE(InfoExtractor):
 
 
 class PatreonIE(PatreonBaseIE):
+    IE_NAME = 'patreon'
     _VALID_URL = r'https?://(?:www\.)?patreon\.com/(?:creation\?hid=|posts/(?:[\w-]+-)?)(?P<id>\d+)'
     _TESTS = [{
         'url': 'http://www.patreon.com/creation?hid=743933',
@@ -109,11 +119,12 @@ class PatreonIE(PatreonBaseIE):
             'comment_count': int,
             'channel_is_verified': True,
             'chapters': 'count:4',
+            'timestamp': 1423689666,
         },
         'params': {
             'noplaylist': True,
             'skip_download': True,
-        }
+        },
     }, {
         'url': 'https://www.patreon.com/posts/episode-166-of-743933',
         'only_matching': True,
@@ -133,7 +144,7 @@ class PatreonIE(PatreonBaseIE):
             'description': 'md5:557a409bd79d3898689419094934ba79',
             'uploader_id': '14936315',
         },
-        'skip': 'Patron-only content'
+        'skip': 'Patron-only content',
     }, {
         # m3u8 video (https://github.com/yt-dlp/yt-dlp/issues/2277)
         'url': 'https://www.patreon.com/posts/video-sketchbook-32452882',
@@ -154,7 +165,7 @@ class PatreonIE(PatreonBaseIE):
             'channel_id': '1641751',
             'channel_url': 'https://www.patreon.com/loish',
             'channel_follower_count': int,
-        }
+        },
     }, {
         # bad videos under media (if media is included). Real one is under post_file
         'url': 'https://www.patreon.com/posts/premium-access-70282931',
@@ -219,6 +230,7 @@ class PatreonIE(PatreonBaseIE):
             'thumbnail': r're:^https?://.+',
         },
         'params': {'skip_download': 'm3u8'},
+        'expected_warnings': ['Failed to parse XML: not well-formed'],
     }, {
         # multiple attachments/embeds
         'url': 'https://www.patreon.com/posts/holy-wars-solos-100601977',
@@ -305,22 +317,33 @@ class PatreonIE(PatreonBaseIE):
                     'channel_follower_count': ('attributes', 'patron_count', {int_or_none}),
                 }))
 
+        # all-lowercase 'referer' so we can smuggle it to Generic, SproutVideo, Vimeo
+        headers = {'referer': 'https://patreon.com/'}
+
         # handle Vimeo embeds
         if traverse_obj(attributes, ('embed', 'provider')) == 'Vimeo':
             v_url = urllib.parse.unquote(self._html_search_regex(
                 r'(https(?:%3A%2F%2F|://)player\.vimeo\.com.+app_id(?:=|%3D)+\d+)',
                 traverse_obj(attributes, ('embed', 'html', {str})), 'vimeo url', fatal=False) or '')
             if url_or_none(v_url) and self._request_webpage(
-                    v_url, video_id, 'Checking Vimeo embed URL',
-                    headers={'Referer': 'https://patreon.com/'},
-                    fatal=False, errnote=False):
+                    v_url, video_id, 'Checking Vimeo embed URL', headers=headers,
+                    fatal=False, errnote=False, expected_status=429):  # 429 is TLS fingerprint rejection
                 entries.append(self.url_result(
                     VimeoIE._smuggle_referrer(v_url, 'https://patreon.com/'),
                     VimeoIE, url_transparent=True))
 
         embed_url = traverse_obj(attributes, ('embed', 'url', {url_or_none}))
-        if embed_url and self._request_webpage(embed_url, video_id, 'Checking embed URL', fatal=False, errnote=False):
-            entries.append(self.url_result(embed_url))
+        if embed_url and (urlh := self._request_webpage(
+                embed_url, video_id, 'Checking embed URL', headers=headers,
+                fatal=False, errnote=False, expected_status=403)):
+            # Vimeo's Cloudflare anti-bot protection will return HTTP status 200 for 404, so we need
+            # to check for "Sorry, we couldn&amp;rsquo;t find that page" in the meta description tag
+            meta_description = clean_html(self._html_search_meta(
+                'description', self._webpage_read_content(urlh, embed_url, video_id, fatal=False), default=None))
+            # Password-protected vids.io embeds return 403 errors w/o --video-password or session cookie
+            if ((urlh.status != 403 and meta_description != 'Sorry, we couldn’t find that page')
+                    or VidsIoIE.suitable(embed_url)):
+                entries.append(self.url_result(smuggle_url(embed_url, headers)))
 
         post_file = traverse_obj(attributes, ('post_file', {dict}))
         if post_file:
@@ -378,7 +401,7 @@ class PatreonIE(PatreonBaseIE):
 
             params.update({'page[cursor]': cursor} if cursor else {})
             response = self._call_api(
-                f'posts/{post_id}/comments', post_id, query=params, note='Downloading comments page %d' % page)
+                f'posts/{post_id}/comments', post_id, query=params, note=f'Downloading comments page {page}')
 
             cursor = None
             for comment in traverse_obj(response, (('data', ('included', lambda _, v: v['type'] == 'comment')), ...)):
@@ -411,15 +434,19 @@ class PatreonIE(PatreonBaseIE):
 
 
 class PatreonCampaignIE(PatreonBaseIE):
-
-    _VALID_URL = r'https?://(?:www\.)?patreon\.com/(?!rss)(?:(?:m/(?P<campaign_id>\d+))|(?P<vanity>[-\w]+))'
+    IE_NAME = 'patreon:campaign'
+    _VALID_URL = r'''(?x)
+        https?://(?:www\.)?patreon\.com/(?:
+            (?:m|api/campaigns)/(?P<campaign_id>\d+)|
+            (?P<vanity>(?!creation[?/]|posts/|rss[?/])[\w-]+)
+        )(?:/posts)?/?(?:$|[?#])'''
     _TESTS = [{
         'url': 'https://www.patreon.com/dissonancepod/',
         'info_dict': {
             'title': 'Cognitive Dissonance Podcast',
             'channel_url': 'https://www.patreon.com/dissonancepod',
             'id': '80642',
-            'description': 'md5:eb2fa8b83da7ab887adeac34da6b7af7',
+            'description': r're:(?s).*We produce a weekly news podcast focusing on stories that deal with skepticism and religion.*',
             'channel_id': '80642',
             'channel': 'Cognitive Dissonance Podcast',
             'age_limit': 0,
@@ -434,31 +461,46 @@ class PatreonCampaignIE(PatreonBaseIE):
         'url': 'https://www.patreon.com/m/4767637/posts',
         'info_dict': {
             'title': 'Not Just Bikes',
-            'channel_follower_count': int,
             'id': '4767637',
             'channel_id': '4767637',
             'channel_url': 'https://www.patreon.com/notjustbikes',
-            'description': 'md5:595c6e7dca76ae615b1d38c298a287a1',
+            'description': r're:(?s).*Not Just Bikes started as a way to explain why we chose to live in the Netherlands.*',
             'age_limit': 0,
             'channel': 'Not Just Bikes',
             'uploader_url': 'https://www.patreon.com/notjustbikes',
-            'uploader': 'Not Just Bikes',
+            'uploader': 'Jason',
             'uploader_id': '37306634',
             'thumbnail': r're:^https?://.*$',
         },
-        'playlist_mincount': 71
+        'playlist_mincount': 71,
+    }, {
+        'url': 'https://www.patreon.com/api/campaigns/4243769/posts',
+        'info_dict': {
+            'title': 'Second Thought',
+            'channel_follower_count': int,
+            'id': '4243769',
+            'channel_id': '4243769',
+            'channel_url': 'https://www.patreon.com/secondthought',
+            'description': r're:(?s).*Second Thought is an educational YouTube channel.*',
+            'age_limit': 0,
+            'channel': 'Second Thought',
+            'uploader_url': 'https://www.patreon.com/secondthought',
+            'uploader': 'JT Chapman',
+            'uploader_id': '32718287',
+            'thumbnail': r're:^https?://.*$',
+        },
+        'playlist_mincount': 201,
     }, {
         'url': 'https://www.patreon.com/dissonancepod/posts',
-        'only_matching': True
+        'only_matching': True,
     }, {
         'url': 'https://www.patreon.com/m/5932659',
-        'only_matching': True
+        'only_matching': True,
+    }, {
+        'url': 'https://www.patreon.com/api/campaigns/4243769',
+        'only_matching': True,
     }]
 
-    @classmethod
-    def suitable(cls, url):
-        return False if PatreonIE.suitable(url) else super(PatreonCampaignIE, cls).suitable(url)
-
     def _entries(self, campaign_id):
         cursor = None
         params = {
@@ -472,7 +514,7 @@ class PatreonCampaignIE(PatreonBaseIE):
         for page in itertools.count(1):
 
             params.update({'page[cursor]': cursor} if cursor else {})
-            posts_json = self._call_api('posts', campaign_id, query=params, note='Downloading posts page %d' % page)
+            posts_json = self._call_api('posts', campaign_id, query=params, note=f'Downloading posts page {page}')
 
             cursor = traverse_obj(posts_json, ('meta', 'pagination', 'cursors', 'next'))
             for post_url in traverse_obj(posts_json, ('data', ..., 'attributes', 'patreon_url')):
@@ -485,14 +527,15 @@ class PatreonCampaignIE(PatreonBaseIE):
 
         campaign_id, vanity = self._match_valid_url(url).group('campaign_id', 'vanity')
         if campaign_id is None:
-            webpage = self._download_webpage(url, vanity, headers={'User-Agent': self.USER_AGENT})
-            campaign_id = self._search_regex(r'https://www.patreon.com/api/campaigns/(\d+)/?', webpage, 'Campaign ID')
+            webpage = self._download_webpage(url, vanity, headers={'User-Agent': self.patreon_user_agent})
+            campaign_id = self._search_nextjs_data(
+                webpage, vanity)['props']['pageProps']['bootstrapEnvelope']['pageBootstrap']['campaign']['data']['id']
 
         params = {
             'json-api-use-default-includes': 'false',
             'fields[user]': 'full_name,url',
             'fields[campaign]': 'name,summary,url,patron_count,creation_count,is_nsfw,avatar_photo_url',
-            'include': 'creator'
+            'include': 'creator',
         }
 
         campaign_response = self._call_api(
